package
Version:
v0.0.0-...-cfbc090
Opens a new window with list of versions in this module.
Published: Aug 9, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Memory interface {
Get(key string) (interface{}, bool)
Update(key string, update func(interface{}, bool) interface{})
Delete(key string)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.